[CalendarServer-changes] [12857] twext/trunk/twext/who/idirectory.py

source_changes at macosforge.org source_changes at macosforge.org
Fri Mar 7 16:53:53 PST 2014


Revision: 12857
          http://trac.calendarserver.org//changeset/12857
Author:   wsanchez at apple.com
Date:     2014-03-07 16:53:53 -0800 (Fri, 07 Mar 2014)
Log Message:
-----------
Clean up docs.
Don't imply that you must be a group (that is, of record type="group") to have members.

Modified Paths:
--------------
    twext/trunk/twext/who/idirectory.py

Modified: twext/trunk/twext/who/idirectory.py
===================================================================
--- twext/trunk/twext/who/idirectory.py	2014-03-08 00:50:40 UTC (rev 12856)
+++ twext/trunk/twext/who/idirectory.py	2014-03-08 00:53:53 UTC (rev 12857)
@@ -462,27 +462,27 @@
 
     def addMembers(members):
         """
         Adds the members to this group.
 
-        @param members: The records of the members to add to this group.
+        @param members: The members to add to this record.
         @type members: An iterable of L{IDirectoryRecord}s.
         """
 
 
     def removeMembers(members):
         """
         Removes the members from this group.
 
-        @param members: The records of the members to remove from this group.
+        @param members: The members to remove from this record.
         @type members: An iterable of L{IDirectoryRecord}s.
         """
 
 
     def setMembers(members):
         """
         Replaces the current members with a new set of members.
 
-        @param members: The records comprising the new set of members.
+        @param members: The new members.
         @type members: An iterable of L{IDirectoryRecord}s.
         """
 
-------------- next part --------------
@@ -462,27 +462,27 @@
     def addMembers(members):
         """
-        Adds the members to this group.
+        Adds the members to this record.
 
@@ -462,27 +462,27 @@
     def removeMembers(members):
         """
-        Removes the members from this group.
+        Removes the members from this record.
 
@@ -462,27 +462,27 @@
     def setMembers(members):
         """
-        Replaces the current members with a new set of members.
+        Replaces the current members of this record.
 
An HTML attachment was scrubbed...
URL: <https://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20140307/59c1a266/attachment-0001.html>


More information about the calendarserver-changes mailing list